CanvasAssetLibrary class abstract

A curated collection of assets available to an editor.

Implementers

Constructors

CanvasAssetLibrary()
const

Properties

categories List<String>
Sorted category keys represented by items.
no setter
hashCode int
The hash code for this object.
no setterinherited
items List<CanvasAssetLibraryItem>
All assets in this library.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

byCategory(String category) List<CanvasAssetLibraryItem>
Returns the assets assigned to category.
bySourceRef(String ref) CanvasAssetLibraryItem?
Finds an asset by its source or thumbnail reference.
intrinsicSizeFor(String ref) → Size2D?
Returns the intrinsic size associated with ref, when known.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited