defaultSize property
Maximum initial extent of the inserted image node.
When intrinsicSize is valid, the largest inserted dimension is defaultSize and the intrinsic aspect ratio is preserved.
Implementation
final double defaultSize;
Maximum initial extent of the inserted image node.
When intrinsicSize is valid, the largest inserted dimension is defaultSize and the intrinsic aspect ratio is preserved.
final double defaultSize;