LocalCanvasAssetLibrary class
An in-memory asset library backed by a fixed list.
- Inheritance
-
- Object
- CanvasAssetLibrary
- LocalCanvasAssetLibrary
Constructors
-
LocalCanvasAssetLibrary(List<
CanvasAssetLibraryItem> items) -
const
Properties
-
categories
→ List<
String> -
Sorted category keys represented by items.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
CanvasAssetLibraryItem> -
All assets in this library.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
byCategory(
String category) → List< CanvasAssetLibraryItem> -
Returns the assets assigned to
category.inherited -
bySourceRef(
String ref) → CanvasAssetLibraryItem? -
Finds an asset by its source or thumbnail reference.
inherited
-
intrinsicSizeFor(
String ref) → Size2D? -
Returns the intrinsic size associated with
ref, when known.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited