FontDef class

Constructors

FontDef({required String family, required String label, List<String> assetPaths = const <String>[]})
const

Properties

assetPaths List<String>
final
family String
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited