Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
IconCatalogItem> -
no setter
-
resolveMap
→ Map<
String, ResolvedIcon> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
String iconRef) → ResolvedIcon? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited