PngExportPort class abstract interface

Host-owned final PNG operation.

The editor supplies one adapter-resolved canonical scene. It has not been passed through a ScenePreparer.

Implementations own any host-specific output validation and delegate final rendering to an authoritative PNG renderer.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
savePng({required CanvasSceneDocument scene, required CanvasPngSpec spec, required String filename}) Future<String>
sharePng({required CanvasSceneDocument scene, required CanvasPngSpec spec, required String filename, String? text}) Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited