resources property
Runtime services used by this editor session.
Resources are captured when the session is created so the renderer, image loading, font handling, inspector, and actions use one consistent resource set. Use a different Key to start a session with different resources.
Implementation
final CanvasRuntimeResources resources;