CanvasHitTestResult class

Annotations

Constructors

CanvasHitTestResult({required Node? leaf, required Node? node})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
leaf → Node?
Topmost editable leaf hit.
final
node → Node?
Topmost selectable/group-level hit.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited