EditorActionContext class
- Annotations
Constructors
- EditorActionContext({required BuildContext buildContext, required CanvasRuntimeResources resources, required UiFeedback ui, required EditorController controller, required EditorSelectionHost selection})
-
const
Properties
- buildContext → BuildContext
-
final
- controller → EditorController
-
Editor state + document mutation capability.
final
- editableScene → CanvasSceneDocument
-
Canonical editable/base scene used by persistence, scene JSON export,
and the object tree.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- renderScene → CanvasSceneDocument
-
Prepared/effective scene used by visual-output paths:
canvas paint, hit testing, snapping, and PNG export.
no setter
- resources → CanvasRuntimeResources
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → EditorSelectionHost
-
Selection capability used by action helpers such as add-and-select.
final
- ui → UiFeedback
-
final
Methods
-
addNode(
Node node) → String -
addNodeAndSelect(
Node node) → String -
bringForward(
) → void -
bringToFront(
) → void -
clearSelection(
) → void -
deleteSelection(
) → void -
duplicateSelection(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redo(
) → void -
selectItems(
Iterable< String> ids, {bool additive = false}) → void -
sendBackward(
) → void -
sendToBack(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
undo(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited