EditorActionDispatcher class

Constructors

EditorActionDispatcher({required Map<EditorActionId, EditorActionSpec> actions, required EditorActionContext context})
const

Properties

actions → Map<EditorActionId, EditorActionSpec>
final
context → EditorActionContext
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canInvoke(EditorActionId id) → bool
invoke(EditorActionId id) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited