Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- addCircle → const EditorActionId
- addEllipse → const EditorActionId
- addImage → const EditorActionId
- addPill → const EditorActionId
- addPolygon → const EditorActionId
- addRect → const EditorActionId
- addRoundRect → const EditorActionId
- addStar → const EditorActionId
- addText → const EditorActionId
- addUnderline → const EditorActionId
- bringForward → const EditorActionId
- bringToFront → const EditorActionId
- copySceneJson → const EditorActionId
- deleteSelection → const EditorActionId
- duplicate → const EditorActionId
- redo → const EditorActionId
- savePng → const EditorActionId
- saveSceneJson → const EditorActionId
- sendBackward → const EditorActionId
- sendToBack → const EditorActionId
- undo → const EditorActionId