EditorActionSpec class

Annotations

Constructors

EditorActionSpec({required EditorActionId id, required EditorToolbarSection section, required EditorActionLabelBuilder labelBuilder, required EditorActionIconBuilder iconBuilder, required EditorActionPredicate isEnabled, required EditorActionPredicate isVisible, required EditorActionInvoke invoke, int priority = 0, String? menuGroup})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
iconBuilder → EditorActionIconBuilder
final
id EditorActionId
final
invoke EditorActionInvoke
final
isEnabled → EditorActionPredicate
final
isVisible → EditorActionPredicate
final
labelBuilder → EditorActionLabelBuilder
final
Optional subgroup label inside section menus.
final
priority int
Higher priority appears earlier within a toolbar/menu section.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
section EditorToolbarSection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited