beginEditSession abstract method
Opens a session that coalesces repeated mutations into one undo entry.
Returns an idempotent callback that closes the active session.
Implementation
VoidCallback beginEditSession();
Opens a session that coalesces repeated mutations into one undo entry.
Returns an idempotent callback that closes the active session.
VoidCallback beginEditSession();