getField<T> abstract method

FieldState<T> getField<T>(
  1. ElementId nodeId,
  2. CanvasFieldKey fieldKey
)

Reads the effective presentation value of a registered field.

The value may come from the resolved/rendered scene even though persistent mutations are applied to the canonical base scene.

Do not use this value as the starting point for a canonical functional update; use updateField for read-modify-write behavior.

Implementation

FieldState<T> getField<T>(rt.ElementId nodeId, rt.CanvasFieldKey fieldKey);