updateField<T> abstract method

void updateField<T>(
  1. ElementId nodeId,
  2. CanvasFieldKey fieldKey,
  3. T update(
    1. T currentCanonicalValue
    )
)

Updates a registered field from its current canonical value.

update receives the value read from the latest canonical base scene, including the latest in-flight transaction state. It never starts from the value returned by getField.

Missing, stale, wrong-kind, or source-document-denied targets are ignored without invoking update.

Implementation

void updateField<T>(
  rt.ElementId nodeId,
  rt.CanvasFieldKey fieldKey,
  T Function(T currentCanonicalValue) update,
);