updateUniformScaleAround abstract method
Scale around an anchor point expressed in the node's parent space.
Implementation
void updateUniformScaleAround(
rt.ElementId id,
rt.Vec2 anchorParent,
double mul,
);
Scale around an anchor point expressed in the node's parent space.
void updateUniformScaleAround(
rt.ElementId id,
rt.Vec2 anchorParent,
double mul,
);