resolve abstract method
Resolves the canonical document into the runtime scene used for rendering.
Implementation
rt.CanvasSceneDocument resolve(TSourceDocument doc, Object? ctx);
Resolves the canonical document into the runtime scene used for rendering.
rt.CanvasSceneDocument resolve(TSourceDocument doc, Object? ctx);