EditorExtensionContext<TSourceDocument> class
- Annotations
Constructors
-
EditorExtensionContext({required EditorDocumentHost<
TSourceDocument> documentHost, required VoidCallback requestRebuild}) -
const
Properties
-
documentHost
→ EditorDocumentHost<
TSourceDocument> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestRebuild → VoidCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited