showTransformChromeNode property

NodeMovePermission? showTransformChromeNode
final

Custom transform-chrome visibility rule.

This is intentionally separate from canMoveNode. Some nodes may be non-movable for placement/layout reasons and should not show resize handles, while other non-movable states may still want their normal selection chrome.

Implementation

final NodeTransformChromePermission? showTransformChromeNode;