showLayersPanel property
Whether the built-in layers panel should be shown when the shell has enough space.
Layers are docked only in wide, standalone layouts.
Implementation
final bool showLayersPanel;
Whether the built-in layers panel should be shown when the shell has enough space.
Layers are docked only in wide, standalone layouts.
final bool showLayersPanel;