EditorToolbarState class

Annotations

Constructors

EditorToolbarState({required bool compact, required bool canUndo, required bool canRedo, required bool hasSelection})
const

Properties

canRedo bool
final
canUndo bool
final
compact bool
final
hashCode int
The hash code for this object.
no setterinherited
hasSelection bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited