commit property
CommitFn
commit
final
Applies field-specific policy and routes the resulting persistent mutation through EditorController.applyEdit.
Implementation
final CommitFn commit;
Applies field-specific policy and routes the resulting persistent mutation through EditorController.applyEdit.
final CommitFn commit;