readNode property
ReadNodeFn?
readNode
final
Reads from a runtime node in the effective rendered scene.
Implementation
final ReadNodeFn? readNode;
Reads from a runtime node in the effective rendered scene.
final ReadNodeFn? readNode;