FieldState<T> class final

Typed state for a single inspector field.

A null disabledReason means the field can be edited.

Constructors

FieldState(T value, {String? disabledReason})
const

Properties

disabledReason String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited