InspectorBuilder typedef
InspectorBuilder =
Widget? Function(InspectorContext context)
Builds the complete inspector body for the current selection.
Return null when this builder does not own the current selection and the earlier builder should get an opportunity to handle it.
Implementation
typedef InspectorBuilder = Widget? Function(InspectorContext context);