InspectorFieldSpec<T> class

Constructors

InspectorFieldSpec({required CanvasFieldKey fieldKey, required String title, required CommitMode commitMode, required ControlBuilder<T> control, Duration debounce = const Duration(milliseconds: 450), String? semanticSlot})
const

Properties

commitMode → CommitMode
final
control → ControlBuilder<T>
Controls MUST be pure UI: no controller calls, no FieldState dependency.
final
debounce → Duration
Only used when commitMode == debounced.
final
fieldKey → CanvasFieldKey
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticSlot → String?
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited