compactWidth constant

double const compactWidth

Local inspector width below which controls should prefer vertical layouts.

This is intentionally based on the space available to the inspector component, not the width of the overall app window or device.

Implementation

static const double compactWidth = 360;