SelectionChromeMode enum

Controls the editor chrome drawn around the selected object.

This affects presentation only; it does not change selection or permissions.

Inheritance
Available extensions

Values

hidden → const SelectionChromeMode

No selection box, resize handles, or rotate handle.

transformControls → const SelectionChromeMode

Selection frame with resize and rotate controls.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SelectionChromeMode>
A constant List of the values in this enum, in order of their declaration.