SelectionState class final

Shared editor contracts/types that are layer-neutral.

Safe for:

  • application
  • presentation
  • extension packages

Important:

  • this file must not import presentation-layer code
  • higher-level widgets/controllers can depend on this
  • application code can also depend on this
Annotations

Constructors

SelectionState.items(Iterable<String> ids)
factory
SelectionState.none()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
hasItems bool
no setter
ids Set<String>
final
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override