ImageImportPort class abstract

Host-owned import of a user-provided image.

The host may pick, transform, upload, persist, or otherwise prepare the selected image. On success, it returns the durable source reference that should be stored in the canvas document.

Constructors

ImageImportPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

importImage({required ImageImportSource source}) Future<ImageImportResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited