CanvasRuntimeResources class
Runtime assets required to render and edit existing scenes.
Asset libraries/elements pickers are optional editor features. They should be passed through extensions instead of being part of this runtime object.
Constructors
- CanvasRuntimeResources({required CanvasFontAssets fonts, required IconCatalogPort icons, required CanvasMediaResolver media})
-
const
Properties
-
fallbackFontFamilies
→ Iterable<
String> -
no setter
- fonts → CanvasFontAssets
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icons → IconCatalogPort
-
final
- media → CanvasMediaResolver
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ensureFontsForScene(
CanvasSceneDocument scene, {bool includeFallbackFonts = true, bool includeIconFonts = true}) → Future< void> -
fontFamiliesForScene(
CanvasSceneDocument scene, {bool includeFallbackFonts = true, bool includeIconFonts = true}) → Set< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited