extensions property
Optional feature composition for this editor session.
Extensions and their runtime contributions are captured when the session is created. Rebuild with a different Key to use a different extension set.
Implementation
final List<EditorExtension<TSourceDocument>> extensions;