initialDocument property

TSourceDocument initialDocument
final

The source document used to create a new editor session.

Rebuilding this surface with the same key does not replace the active edited source document. Use a different Key to intentionally create a fresh session from another document.

Implementation

final TSourceDocument initialDocument;