CanvasViewportBehavior class abstract

Optional viewport behavior extension.

The viewport provides:

  • hit testing
  • normal selection
  • drag session lifecycle
  • snapping
  • pan/zoom

Optional behaviors may fully handle a selection interaction or provide foreground UI.

Constructors

CanvasViewportBehavior()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildForeground(BuildContext context, CanvasViewportBehaviorContext ctx) Widget?
handleTapSelection(BuildContext context, CanvasViewportBehaviorContext ctx, CanvasHitTestResult hit) bool
listenable(BuildContext context) Listenable?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveDragStartSelection(BuildContext context, CanvasViewportBehaviorContext ctx, CanvasHitTestResult hit, ScaleStartDetails details) CanvasDragStartIntent?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited