CanvasViewportBehaviorContext class
- Annotations
Constructors
- CanvasViewportBehaviorContext({required RenderSnapshot render, required EditorSelectionHost selection, required EditorController controller})
-
const
Properties
- controller → EditorController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- render → RenderSnapshot
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → EditorSelectionHost
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited