Canonical document capability for hosted/source-document editors.
Use this when an extension needs to read or update the host application's source document, rather than only the resolved runtime scene.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ ValueListenable<
TSourceDocument> -
Listenable canonical source document.
no setter
- sourceDocument → TSourceDocument
-
Current canonical source document.
no setter
Methods
-
applyEdit(
EditorEdit edit) → ElementId? - Applies a generic edit to the canonical base scene.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setResolveContext(
Object? context) → void - Updates resolve context used by the adapter/render pipeline.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSourceDocument(
TSourceDocument update(TSourceDocument document)) → void - Applies a source-document-level mutation.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited