EditorEditResult class
Result of applying an EditorEdit to a base scene.
primaryId is useful for follow-up selection, especially add/duplicate. deletedIds and duplicatedIds let document adapters clean up or remap app-specific canonical data.
- Annotations
Constructors
-
EditorEditResult({required CanvasSceneDocument scene, ElementId? primaryId, Set<
String> deletedIds = const <rt.ElementId>{}, Map<ElementId, ElementId> duplicatedIds = const <rt.ElementId, rt.ElementId>{}}) -
const
Properties
-
deletedIds
→ Set<
String> -
final
-
duplicatedIds
→ Map<
ElementId, ElementId> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scene → CanvasSceneDocument
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited