Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addNode(
Node node) → EditorEdit -
bringForward(
ElementId id) → EditorEdit -
bringToFront(
ElementId id) → EditorEdit -
deleteSubtree(
ElementId id) → EditorEdit -
duplicateSubtree(
ElementId id) → EditorEdit -
renameElement(
ElementId id, String? name) → EditorEdit -
replaceNode(
ElementId id, Node updated) → EditorEdit -
sendBackward(
ElementId id) → EditorEdit -
sendToBack(
ElementId id) → EditorEdit -
setElementHidden(
ElementId id, ) → EditorEdit -
setElementLocked(
ElementId id, bool locked) → EditorEdit -
updateNode(
ElementId id, Node update(Node node)) → EditorEdit -
updateScene(
CanvasSceneDocument update(CanvasSceneDocument scene)) → EditorEdit