EditorInteractionPolicy class

Annotations

Constructors

EditorInteractionPolicy({NodeMovePermission? canMoveNode, NodeTransformChromePermission? showTransformChromeNode})
const

Properties

canMoveNode → NodeMovePermission?
Custom movement rule.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showTransformChromeNode → NodeMovePermission?
Custom transform-chrome visibility rule.
final

Methods

canMove(Node node) → bool
merge(EditorInteractionPolicy other) → EditorInteractionPolicy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showTransformChrome(Node node) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited