Selection capability exposed to editor extensions.
Extensions should depend on this capability rather than the concrete selection controller.
- Implemented types
Properties
- firstId → String?
-
First selected item ID, when item selection is non-empty.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → SelectionState
-
The current value of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
clearSelection(
) → void - Clears the current item selection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
selectItems(
Iterable< String> ids, {bool additive = false}) → void - Selects canvas item IDs.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited