readNode property
ReadCanonicalNodeFn?
readNode
final
Presentation read from a runtime node and its effective scene context.
Implementation
final ReadNodeFn? readNode;
Presentation read from a runtime node and its effective scene context.
final ReadNodeFn? readNode;