readNode property
ReadNodeFn?
readNode
final
Reads from a runtime node with its effective rendered scene context.
Implementation
final ReadNodeFn? readNode;
Reads from a runtime node with its effective rendered scene context.
final ReadNodeFn? readNode;