InspectorContext class

Immutable values available while building the inspector.

Annotations

Constructors

InspectorContext({required ElementId? selectedId, required EditorSelectionHost selection, required EditorController controller, required CanvasSceneDocument editableScene, required CanvasSceneDocument renderedScene, required CanvasRuntimeResources resources, required InspectorFieldRowBuilder fieldRowBuilder})
const

Properties

controller EditorController
final
editableScene → CanvasSceneDocument
Canonical scene edited by commands and field commits.
final
fieldRowBuilder InspectorFieldRowBuilder
final
hashCode int
The hash code for this object.
no setterinherited
renderedScene → CanvasSceneDocument
Prepared/resolved scene currently displayed by the renderer.
final
resources CanvasRuntimeResources
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedEditableNode → Node?
no setter
selectedId → ElementId?
Selected item ID when exactly one canvas item is selected.
final
selectedRenderedNode → Node?
no setter
selection EditorSelectionHost
final

Methods

fieldRow<T>(ElementId nodeId, InspectorFieldSpec<T> spec) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited