InspectorSectionBuilder typedef
InspectorSectionBuilder =
Widget? Function(InspectorContext context)
Builds additive content inside the standard inspector for the current single-item selection.
Returning null means this section does not apply to the current selection.
These sections are only used when no exclusive InspectorBuilder handles the selection.
Implementation
typedef InspectorSectionBuilder = Widget? Function(InspectorContext context);