StaticEditorExtension<TSourceDocument> class
- Inheritance
-
- Object
- EditorExtension<
TSourceDocument> - StaticEditorExtension
Constructors
-
StaticEditorExtension({ScenePreparer? scenePreparer, Map<
CanvasFieldKey, FieldCodec> fieldCodecs = const <CanvasFieldKey, FieldCodec>{}, EditorSurfaceFeatures surfaceFeatures = const EditorSurfaceFeatures(), List<EditorActionSpec> actionSpecs = const <EditorActionSpec>[]}) -
const
Properties
-
actionSpecs
→ List<
EditorActionSpec> -
final
-
fieldCodecs
→ Map<
CanvasFieldKey, FieldCodec> -
Additional or overriding document field codecs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inspectorFieldRowBuilder → InspectorFieldRowBuilder?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scenePreparer → ScenePreparer?
-
Optional transformation applied after document resolution and before the
runtime render pipeline builds its snapshot.
final
- surfaceFeatures → EditorSurfaceFeatures
-
Construction-time configuration for the live editor surface.
final
Methods
-
attach(
EditorExtensionContext< TSourceDocument> context) → void -
inherited
-
buildProviders(
) → List< SingleChildWidget> -
inherited
-
dispose(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited