UiFeedback class abstract
Action-scoped presentation feedback supplied by the editor surface.
Editor actions may request busy-state UI or display a user-facing message, but do not know how the surrounding editor shell implements either behavior.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hideSpinner(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showSpinner(
) → void -
toast(
String msg) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited