BackgroundRemovalFailure class final
Expected host-owned background-removal failure.
message, when supplied, must already be safe to present to the user. Internal exceptions, provider diagnostics, stack traces, storage details, and implementation-specific failure information must not be exposed here.
- Inheritance
-
- Object
- BackgroundRemovalResult
- BackgroundRemovalFailure
Constructors
- BackgroundRemovalFailure({required BackgroundRemovalFailureKind kind, String? message})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → BackgroundRemovalFailureKind
-
final
- message → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited